@@ -9,10 +9,11 @@ use Net::Whois::Norid;
 
 $Net::Whois::Raw::CHECK_FAIL = 1;
 
-use version; our $VERSION = qv('0.6.1');
+use version; our $VERSION = qv('0.7.0');
 
 use parent qw/Exporter/;
-our @EXPORT_OK = qw/all domain2orgnr orgnr_ok orgnr2domains/;
+our @EXPORT      = ();
+our @EXPORT_OK   = qw/all domain2orgnr orgnr_ok orgnr2domains/;
 our %EXPORT_TAGS = ( 'all' => [qw/domain2orgnr orgnr_ok orgnr2domains/] );
 
 sub domain2orgnr {
@@ -55,9 +56,9 @@ sub orgnr_ok {
     $sum += $digits[$_] * $weights->[$_] for ( 0 .. 7 );
 
     my $rem = $sum % 11;
-    my $control_digit;
-    $rem == 0 ? $control_digit = 0 : $control_digit = 11 - $rem;
-    return 0 if $rem == 1;                         # Invalid number if control digit is 10
+    my $control_digit = ( $rem == 0 ? 0 : 11 - $rem );
+
+    return 0 if $rem == 1;    # Invalid number if control digit is 10
     return 0 if $control_digit ne $digits[8];
 
     return join ' ',
@@ -76,7 +77,7 @@ No::OrgNr - Utility functions for Norwegian organizations' ID numbers
 
 =head1 VERSION
 
-This document describes No::OrgNr version 0.6.1
+This document describes No::OrgNr version 0.7.0
 
 
 =head1 SYNOPSIS
